@@ -25,7 +25,7 @@ void QuickDialog::create(const QString &file, const QVariantMap &props)
 {
     auto engine = new QQmlApplicationEngine(this);
     auto context = new KLocalizedContext(engine);
-    context->setTranslationDomain(TRANSLATION_DOMAIN);
+    context->setTranslationDomain(QStringLiteral(TRANSLATION_DOMAIN));
     engine->rootContext()->setContextObject(context);
 
     engine->setInitialProperties(props);
@@ -48,21 +48,16 @@ void QuickDialog::create(const QString &file, const QVariantMap &props)
     QTimer::singleShot(0, m_theDialog, SLOT(present()));
 }
 
-bool QuickDialog::exec()
-{
-    if (!m_theDialog) {
-        qWarning() << "Failed to load dialog, cannot exec";
-        return false;
-    }
-    return m_execLoop.exec() == 0;
-}
-
 void QuickDialog::reject()
 {
-    m_execLoop.exit(1);
+    Q_EMIT rejected();
+    Q_EMIT finished(DialogResult::Rejected);
+    deleteLater();
 }
 
 void QuickDialog::accept()
 {
-    m_execLoop.quit();
+    Q_EMIT accepted();
+    Q_EMIT finished(DialogResult::Accepted);
+    deleteLater();
 }
