@@ -172,6 +172,7 @@ uint RemoteDesktopPortal::SelectDevices(const QDBusObjectPath &handle,
 std::pair<PortalResponse::Response, QVariantMap> continueStart(RemoteDesktopSession *session, ScreenCastPortal::PersistMode persist)
 {
     QVariantMap results;
+    QPointer<RemoteDesktopSession> guardedSession(session);
     if (session->screenSharingEnabled()) {
         WaylandIntegration::Streams streams;
         const auto screens = qGuiApp->screens();
@@ -187,6 +188,10 @@ std::pair<PortalResponse::Response, QVariantMap> continueStart(RemoteDesktopSess
             streams << WaylandIntegration::startStreamingWorkspace(Screencasting::Metadata);
         }
 
+        if (!guardedSession) {
+            return {PortalResponse::OtherError, {}};
+        }
+
         session->setStreams(streams);
         results.insert(QStringLiteral("streams"), QVariant::fromValue<WaylandIntegration::Streams>(streams));
     } else {
